.. image:: https://readthedocs.org/projects/sqlite-bedrock-packs/badge/?version=latest
    :target: https://sqlite-bedrock-packs.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

SQLite bedrock packs
====================
Python package that loads data from Minecraft: Bedrock Edition packs into
SQLite database.

Documentation
-------------

If you're looking for documentation please visit:

https://sqlite-bedrock-packs.readthedocs.io/en/latest/

Installation
------------

.. code-block:: bash

   pip install sqlite-bedrock-packs
